@@ -32,32 +32,32 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_COMMAND_H_
-#define _D_DOWNLOAD_COMMAND_H_
+#ifndef D_DOWNLOAD_COMMAND_H
+#define D_DOWNLOAD_COMMAND_H
 
 #include "AbstractCommand.h"
 
+#include <unistd.h>
+
 namespace aria2 {
 
-class Decoder;
 class PeerStat;
+class StreamFilter;
 #ifdef ENABLE_MESSAGE_DIGEST
-class MessageDigestContext;
+class MessageDigest;
 #endif // ENABLE_MESSAGE_DIGEST
 
 class DownloadCommand : public AbstractCommand {
 private:
-  unsigned char* _buf;
+  time_t startupIdleTime_;
+  unsigned int lowestDownloadSpeedLimit_;
+  SharedHandle<PeerStat> peerStat_;
 
-  time_t startupIdleTime;
-  unsigned int lowestDownloadSpeedLimit;
-  SharedHandle<PeerStat> peerStat;
+  bool pieceHashValidationEnabled_;
 
 #ifdef ENABLE_MESSAGE_DIGEST
 
-  bool _pieceHashValidationEnabled;
-
-  SharedHandle<MessageDigestContext> _messageDigestContext;
+  SharedHandle<MessageDigest> messageDigest_;
 
 #endif // ENABLE_MESSAGE_DIGEST
 
@@ -66,15 +66,17 @@ private:
                          const std::string& actualPieceHash);
 
   void checkLowestDownloadSpeed() const;
+
+  SharedHandle<StreamFilter> streamFilter_;
+
+  bool sinkFilterOnly_;
 protected:
-  SharedHandle<Decoder> _transferEncodingDecoder;
-
-  SharedHandle<Decoder> _contentEncodingDecoder;
-
   virtual bool executeInternal();
 
   virtual bool prepareForNextSegment();
 
+  // This is file local offset
+  virtual off_t getRequestEndOffset() const = 0;
 public:
   DownloadCommand(cuid_t cuid,
                   const SharedHandle<Request>& req,
@@ -84,19 +86,24 @@ public:
                   const SharedHandle<SocketCore>& s);
   virtual ~DownloadCommand();
 
-  void setTransferEncodingDecoder(const SharedHandle<Decoder>& decoder);
-
-  void setContentEncodingDecoder(const SharedHandle<Decoder>& decoder);
-
-  void setStartupIdleTime(time_t startupIdleTime) {
-    this->startupIdleTime = startupIdleTime;
+  const SharedHandle<StreamFilter>& getStreamFilter() const
+  {
+    return streamFilter_;
   }
 
-  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit) {
-    this->lowestDownloadSpeedLimit = lowestDownloadSpeedLimit;
+  void installStreamFilter(const SharedHandle<StreamFilter>& streamFilter);
+
+  void setStartupIdleTime(time_t startupIdleTime)
+  {
+    startupIdleTime_ = startupIdleTime;
+  }
+
+  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit)
+  {
+    lowestDownloadSpeedLimit_ = lowestDownloadSpeedLimit;
   }
 };
 
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_COMMAND_H_
+#endif // D_DOWNLOAD_COMMAND_H
