@@ -50,6 +50,7 @@
 #include "a2functional.h"
 #include "TimeA2.h"
 #include "array_fun.h"
+#include "Request.h"
 
 namespace aria2 {
 
@@ -59,9 +60,11 @@ HttpRequest::HttpRequest():contentEncodingEnabled_(true),
                            userAgent_(USER_AGENT),
                            noCache_(true),
                            acceptGzip_(false),
-                           endOffsetOverride_(false)
+                           endOffsetOverride_(0)
 {}
 
+HttpRequest::~HttpRequest() {}
+
 void HttpRequest::setSegment(const SharedHandle<Segment>& segment)
 {
   segment_ = segment;
@@ -74,7 +77,7 @@ void HttpRequest::setRequest(const SharedHandle<Request>& request)
 
 off_t HttpRequest::getStartByte() const
 {
-  if(segment_.isNull()) {
+  if(!segment_) {
     return 0;
   } else {
     return fileEntry_->gtoloff(segment_->getPositionToWrite());
@@ -83,7 +86,7 @@ off_t HttpRequest::getStartByte() const
 
 off_t HttpRequest::getEndByte() const
 {
-  if(segment_.isNull() || request_.isNull()) {
+  if(!segment_ || !request_) {
     return 0;
   } else {
     if(request_->isPipeliningEnabled()) {
@@ -99,7 +102,7 @@ off_t HttpRequest::getEndByte() const
 RangeHandle HttpRequest::getRange() const
 {
   // content-length is always 0
-  if(segment_.isNull()) {
+  if(!segment_) {
     return SharedHandle<Range>(new Range());
   } else {
     return SharedHandle<Range>(new Range(getStartByte(), getEndByte(),
@@ -109,7 +112,7 @@ RangeHandle HttpRequest::getRange() const
 
 bool HttpRequest::isRangeSatisfied(const RangeHandle& range) const
 {
-  if(segment_.isNull()) {
+  if(!segment_) {
     return true;
   }
   if((getStartByte() == range->getStartByte()) &&
@@ -123,7 +126,8 @@ bool HttpRequest::isRangeSatisfied(const RangeHandle& range) const
   }  
 }
 
-static std::string getHostText(const std::string& host, uint16_t port)
+namespace {
+std::string getHostText(const std::string& host, uint16_t port)
 {
   std::string hosttext = host;
   if(!(port == 80 || port == 443)) {
@@ -131,15 +135,16 @@ static std::string getHostText(const std::string& host, uint16_t port)
   }
   return hosttext;
 }
+} // namespace
 
 std::string HttpRequest::createRequest()
 {
   authConfig_ = authConfigFactory_->createAuthConfig(request_, option_);
   std::string requestLine = request_->getMethod();
   requestLine += " ";
-  if(!proxyRequest_.isNull()) {
+  if(proxyRequest_) {
     if(getProtocol() == Request::PROTO_FTP &&
-       request_->getUsername().empty() && !authConfig_.isNull()) {
+       request_->getUsername().empty() && authConfig_) {
       // Insert user into URI, like ftp://USER@host/
       std::string uri = getCurrentURI();
       assert(uri.size() >= 6);
@@ -190,7 +195,7 @@ std::string HttpRequest::createRequest()
   if(!request_->isKeepAliveEnabled() && !request_->isPipeliningEnabled()) {
     builtinHds.push_back(std::make_pair("Connection:", "close"));
   }
-  if(!segment_.isNull() && segment_->getLength() > 0 && 
+  if(segment_ && segment_->getLength() > 0 && 
      (request_->isPipeliningEnabled() || getStartByte() > 0)) {
     std::string rangeHeader = "bytes=";
     rangeHeader += util::itos(getStartByte());
@@ -203,17 +208,17 @@ std::string HttpRequest::createRequest()
     }
     builtinHds.push_back(std::make_pair("Range:", rangeHeader));
   }
-  if(!proxyRequest_.isNull()) {
+  if(proxyRequest_) {
     if(request_->isKeepAliveEnabled() || request_->isPipeliningEnabled()) {
       builtinHds.push_back(std::make_pair("Proxy-Connection:", "Keep-Alive"));
     } else {
       builtinHds.push_back(std::make_pair("Proxy-Connection:", "close"));
     }
   }
-  if(!proxyRequest_.isNull() && !proxyRequest_->getUsername().empty()) {
+  if(proxyRequest_ && !proxyRequest_->getUsername().empty()) {
     builtinHds.push_back(getProxyAuthString());
   }
-  if(!authConfig_.isNull()) {
+  if(authConfig_) {
     builtinHds.push_back
       (std::make_pair("Authorization:",
                       strconcat("Basic ",
@@ -222,7 +227,7 @@ std::string HttpRequest::createRequest()
   if(getPreviousURI().size()) {
     builtinHds.push_back(std::make_pair("Referer:", getPreviousURI()));
   }
-  if(!cookieStorage_.isNull()) {
+  if(cookieStorage_) {
     std::string cookiesValue;
     std::vector<Cookie> cookies =
       cookieStorage_->criteriaFind
@@ -268,7 +273,7 @@ std::string HttpRequest::createRequest()
 
 std::string HttpRequest::createProxyRequest() const
 {
-  assert(!proxyRequest_.isNull());
+  assert(proxyRequest_);
   std::string hostport = getURIHost();
   strappend(hostport, ":", util::uitos(getPort()));
 
@@ -342,12 +347,12 @@ void HttpRequest::setProxyRequest(const SharedHandle<Request>& proxyRequest)
 
 bool HttpRequest::isProxyRequestSet() const
 {
-  return !proxyRequest_.isNull();
+  return proxyRequest_;
 }
 
 bool HttpRequest::authenticationUsed() const
 {
-  return !authConfig_.isNull();
+  return authConfig_;
 }
 
 const SharedHandle<AuthConfig>& HttpRequest::getAuthConfig() const
@@ -355,4 +360,75 @@ const SharedHandle<AuthConfig>& HttpRequest::getAuthConfig() const
   return authConfig_;
 }
 
+uint64_t HttpRequest::getEntityLength() const
+{
+  assert(fileEntry_);
+  return fileEntry_->getLength();
+}
+
+const std::string& HttpRequest::getHost() const
+{
+  return request_->getHost();
+}
+
+uint16_t HttpRequest::getPort() const
+{
+  return request_->getPort();
+}
+
+const std::string& HttpRequest::getMethod() const
+{
+  return request_->getMethod();
+}
+
+const std::string& HttpRequest::getProtocol() const
+{
+  return request_->getProtocol();
+}
+
+const std::string& HttpRequest::getCurrentURI() const
+{
+  return request_->getCurrentUri();
+}
+  
+const std::string& HttpRequest::getDir() const
+{
+  return request_->getDir();
+}
+
+const std::string& HttpRequest::getFile() const
+{
+  return request_->getFile();
+}
+
+const std::string& HttpRequest::getQuery() const
+{
+  return request_->getQuery();
+}
+
+const std::string& HttpRequest::getPreviousURI() const
+{
+  return request_->getPreviousUri();
+}
+
+std::string HttpRequest::getURIHost() const
+{
+  return request_->getURIHost();
+}
+
+void HttpRequest::setUserAgent(const std::string& userAgent)
+{
+  userAgent_ = userAgent;
+}
+
+void HttpRequest::setFileEntry(const SharedHandle<FileEntry>& fileEntry)
+{
+  fileEntry_ = fileEntry;
+}
+
+void HttpRequest::setIfModifiedSinceHeader(const std::string& hd)
+{
+  ifModSinceHeader_ = hd;
+}
+
 } // namespace aria2
