@@ -44,66 +44,64 @@
 #include "message.h"
 #include "DlAbortEx.h"
 #include "DlRetryEx.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "A2STR.h"
-#include "Decoder.h"
-#include "ChunkedDecoder.h"
-#ifdef HAVE_LIBZ
-# include "GZipDecoder.h"
-#endif // HAVE_LIBZ
 #include "CookieStorage.h"
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
+#include "ChunkedDecodingStreamFilter.h"
+#include "error_code.h"
+#ifdef HAVE_LIBZ
+# include "GZipDecodingStreamFilter.h"
+#endif // HAVE_LIBZ
 
 namespace aria2 {
 
-HttpResponse::HttpResponse():cuid_(0),
-                             logger_(LogFactory::getInstance())
+HttpResponse::HttpResponse()
+  : cuid_(0)
 {}
 
 HttpResponse::~HttpResponse() {}
 
 void HttpResponse::validateResponse() const
 {
-  const std::string& status = getResponseStatus();
-  if(status >= HttpHeader::S400) {
+  int statusCode = getStatusCode();
+  if(statusCode >= 400) {
     return;
   }
-  if(status == HttpHeader::S304) {
+  if(statusCode == 304) {
     if(httpRequest_->getIfModifiedSinceHeader().empty()) {
-      throw DL_ABORT_EX("Got 304 without If-Modified-Since");
+      throw DL_ABORT_EX2("Got 304 without If-Modified-Since",
+                         error_code::HTTP_PROTOCOL_ERROR);
     }
-  } else if(status == HttpHeader::S301 ||
-     status == HttpHeader::S302 ||
-     status == HttpHeader::S303 ||
-     status == HttpHeader::S307) {
+  } else if(statusCode == 301 ||
+            statusCode == 302 ||
+            statusCode == 303 ||
+            statusCode == 307) {
     if(!httpHeader_->defined(HttpHeader::LOCATION)) {
-      throw DL_ABORT_EX
-        (StringFormat(EX_LOCATION_HEADER_REQUIRED,
-                      util::parseUInt(status)).str());
+      throw DL_ABORT_EX2(fmt(EX_LOCATION_HEADER_REQUIRED, statusCode),
+                         error_code::HTTP_PROTOCOL_ERROR);
     }
     return;
-  } else if(status == HttpHeader::S200 ||
-            status == HttpHeader::S206) {
+  } else if(statusCode == 200 || statusCode == 206) {
     if(!httpHeader_->defined(HttpHeader::TRANSFER_ENCODING)) {
       // compare the received range against the requested range
       RangeHandle responseRange = httpHeader_->getRange();
       if(!httpRequest_->isRangeSatisfied(responseRange)) {
         throw DL_ABORT_EX2
-          (StringFormat
-           (EX_INVALID_RANGE_HEADER,
-            util::itos(httpRequest_->getStartByte(), true).c_str(),
-            util::itos(httpRequest_->getEndByte(), true).c_str(),
-            util::uitos(httpRequest_->getEntityLength(), true).c_str(),
-            util::itos(responseRange->getStartByte(), true).c_str(),
-            util::itos(responseRange->getEndByte(), true).c_str(),
-            util::uitos(responseRange->getEntityLength(), true).c_str()).str(),
-           downloadresultcode::CANNOT_RESUME);
+          (fmt(EX_INVALID_RANGE_HEADER,
+               util::itos(httpRequest_->getStartByte(), true).c_str(),
+               util::itos(httpRequest_->getEndByte(), true).c_str(),
+               util::uitos(httpRequest_->getEntityLength(), true).c_str(),
+               util::itos(responseRange->getStartByte(), true).c_str(),
+               util::itos(responseRange->getEndByte(), true).c_str(),
+               util::uitos(responseRange->getEntityLength(), true).c_str()),
+           error_code::CANNOT_RESUME);
       }
     }
   } else {
-    throw DL_ABORT_EX
-      (StringFormat("Unexpected status %s", status.c_str()).str());
+    throw DL_ABORT_EX2(fmt("Unexpected status %d", statusCode),
+                       error_code::HTTP_PROTOCOL_ERROR);
   }
 }
 
@@ -120,32 +118,31 @@ std::string HttpResponse::determinFilename() const
       return file;
     }
   } else {
-    if(logger_->info()) {
-      logger_->info(MSG_CONTENT_DISPOSITION_DETECTED,
-                    util::itos(cuid_).c_str(), contentDisposition.c_str());
-    }
+    A2_LOG_INFO(fmt(MSG_CONTENT_DISPOSITION_DETECTED,
+                    cuid_,
+                    contentDisposition.c_str()));
     return contentDisposition;
   }
 }
 
 void HttpResponse::retrieveCookie()
 {
+  Time now;
   std::vector<std::string> v = httpHeader_->get(HttpHeader::SET_COOKIE);
   for(std::vector<std::string>::const_iterator itr = v.begin(), eoi = v.end();
       itr != eoi; ++itr) {
-    httpRequest_->getCookieStorage()->parseAndStore(*itr,
-                                                    httpRequest_->getHost(),
-                                                    httpRequest_->getDir());
+    httpRequest_->getCookieStorage()->parseAndStore
+      (*itr, httpRequest_->getHost(), httpRequest_->getDir(), now.getTime());
   }
 }
 
 bool HttpResponse::isRedirect() const
 {
-  const std::string& status = getResponseStatus();
-  return (HttpHeader::S301 == status ||
-          HttpHeader::S302 == status ||
-          HttpHeader::S303 == status ||
-          HttpHeader::S307 == status) &&
+  int statusCode = getStatusCode();
+  return (301 == statusCode ||
+          302 == statusCode ||
+          303 == statusCode ||
+          307 == statusCode) &&
     httpHeader_->defined(HttpHeader::LOCATION);
 }
 
@@ -153,15 +150,14 @@ void HttpResponse::processRedirect()
 {
   
   if(httpRequest_->getRequest()->redirectUri(getRedirectURI())) {
-    if(logger_->info()) {
-      logger_->info(MSG_REDIRECT, util::itos(cuid_).c_str(),
-                    httpRequest_->getRequest()->getCurrentUri().c_str());
-    }
+    A2_LOG_INFO(fmt(MSG_REDIRECT,
+                    cuid_,
+                    httpRequest_->getRequest()->getCurrentUri().c_str()));
   } else {
     throw DL_RETRY_EX
-      (StringFormat("CUID#%s - Redirect to %s failed. It may not be a valid"
-                    " URI.", util::itos(cuid_).c_str(),
-                    httpRequest_->getRequest()->getCurrentUri().c_str()).str());
+      (fmt("CUID#%lld - Redirect to %s failed. It may not be a valid URI.",
+           cuid_,
+           httpRequest_->getRequest()->getCurrentUri().c_str()));
   }
 }
 
@@ -177,20 +173,21 @@ bool HttpResponse::isTransferEncodingSpecified() const
 
 std::string HttpResponse::getTransferEncoding() const
 {
-  // TODO See TODO in getTransferEncodingDecoder()
+  // TODO See TODO in getTransferEncodingStreamFilter()
   return httpHeader_->getFirst(HttpHeader::TRANSFER_ENCODING);
 }
 
-SharedHandle<Decoder> HttpResponse::getTransferEncodingDecoder() const
+SharedHandle<StreamFilter> HttpResponse::getTransferEncodingStreamFilter() const
 {
+  SharedHandle<StreamFilter> filter;
   // TODO Transfer-Encoding header field can contains multiple tokens. We should
   // parse the field and retrieve each token.
   if(isTransferEncodingSpecified()) {
     if(getTransferEncoding() == HttpHeader::CHUNKED) {
-      return SharedHandle<Decoder>(new ChunkedDecoder());
+      filter.reset(new ChunkedDecodingStreamFilter());
     }
   }
-  return SharedHandle<Decoder>();
+  return filter;
 }
 
 bool HttpResponse::isContentEncodingSpecified() const
@@ -203,20 +200,21 @@ const std::string& HttpResponse::getContentEncoding() const
   return httpHeader_->getFirst(HttpHeader::CONTENT_ENCODING);
 }
 
-SharedHandle<Decoder> HttpResponse::getContentEncodingDecoder() const
+SharedHandle<StreamFilter> HttpResponse::getContentEncodingStreamFilter() const
 {
+  SharedHandle<StreamFilter> filter;
 #ifdef HAVE_LIBZ
   if(getContentEncoding() == HttpHeader::GZIP ||
      getContentEncoding() == HttpHeader::DEFLATE) {
-    return SharedHandle<Decoder>(new GZipDecoder());
+    filter.reset(new GZipDecodingStreamFilter());
   }
 #endif // HAVE_LIBZ
-  return SharedHandle<Decoder>();
+  return filter;
 }
 
 uint64_t HttpResponse::getContentLength() const
 {
-  if(httpHeader_.isNull()) {
+  if(!httpHeader_) {
     return 0;
   } else {
     return httpHeader_->getRange()->getContentLength();
@@ -225,7 +223,7 @@ uint64_t HttpResponse::getContentLength() const
 
 uint64_t HttpResponse::getEntityLength() const
 {
-  if(httpHeader_.isNull()) {
+  if(!httpHeader_) {
     return 0;
   } else {
     return httpHeader_->getRange()->getEntityLength();
@@ -234,11 +232,12 @@ uint64_t HttpResponse::getEntityLength() const
 
 std::string HttpResponse::getContentType() const
 {
-  if(httpHeader_.isNull()) {
+  if(!httpHeader_) {
     return A2STR::NIL;
   } else {
-    return
-      util::split(httpHeader_->getFirst(HttpHeader::CONTENT_TYPE), ";").first;
+    std::pair<std::string, std::string> p;
+    util::divide(p, httpHeader_->getFirst(HttpHeader::CONTENT_TYPE), ';');
+    return p.first;
   }
 }
 
@@ -252,10 +251,9 @@ void HttpResponse::setHttpRequest(const SharedHandle<HttpRequest>& httpRequest)
   httpRequest_ = httpRequest;
 }
 
-// TODO return std::string
-const std::string& HttpResponse::getResponseStatus() const
+int HttpResponse::getStatusCode() const
 {
-  return httpHeader_->getResponseStatus();
+  return httpHeader_->getStatusCode();
 }
 
 bool HttpResponse::hasRetryAfter() const
