@@ -37,22 +37,19 @@
 #include "DownloadEngine.h"
 #include "Option.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "message.h"
 #include "prefs.h"
 #include "NameResolver.h"
 #include "SocketCore.h"
 #include "FileEntry.h"
 #include "RequestGroup.h"
-#include "DownloadContext.h"
 #include "Segment.h"
 #include "a2functional.h"
 #include "InitiateConnectionCommandFactory.h"
 #include "util.h"
-#include "RequestGroupMan.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
 #include "RecoverableException.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -61,8 +58,8 @@ InitiateConnectionCommand::InitiateConnectionCommand
  const SharedHandle<Request>& req,
  const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
- DownloadEngine* e):
-  AbstractCommand(cuid, req, fileEntry, requestGroup, e)
+ DownloadEngine* e)
+  : AbstractCommand(cuid, req, fileEntry, requestGroup, e)
 {
   setTimeout(getOption()->getAsInt(PREF_DNS_TIMEOUT));
   // give a chance to be executed in the next loop in DownloadEngine
@@ -77,7 +74,7 @@ bool InitiateConnectionCommand::executeInternal() {
   std::string hostname;
   uint16_t port;
   SharedHandle<Request> proxyRequest = createProxyRequest();
-  if(proxyRequest.isNull()) {
+  if(!proxyRequest) {
     hostname = getRequest()->getHost();
     port = getRequest()->getPort();
   } else {
@@ -99,14 +96,13 @@ bool InitiateConnectionCommand::executeInternal() {
     // Catch exception and retry another address.
     // See also AbstractCommand::checkIfConnectionEstablished
 
-    // TODO ipaddr might not be used if pooled sockt was found.
+    // TODO ipaddr might not be used if pooled socket was found.
     getDownloadEngine()->markBadIPAddress(hostname, ipaddr, port);
     if(!getDownloadEngine()->findCachedIPAddress(hostname, port).empty()) {
-      if(getLogger()->info()) {
-        getLogger()->info(EX_EXCEPTION_CAUGHT, ex);
-        getLogger()->info(MSG_CONNECT_FAILED_AND_RETRY,
-                          util::itos(getCuid()).c_str(), ipaddr.c_str(), port);
-      }
+      A2_LOG_INFO_EX(EX_EXCEPTION_CAUGHT, ex);
+      A2_LOG_INFO(fmt(MSG_CONNECT_FAILED_AND_RETRY,
+                      getCuid(),
+                      ipaddr.c_str(), port));
       Command* command =
         InitiateConnectionCommandFactory::createInitiateConnectionCommand
         (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
