@@ -39,33 +39,35 @@
 #include "DlAbortEx.h"
 #include "Socket.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "message.h"
 #include "prefs.h"
 #include "DownloadFailureException.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "wallclock.h"
 #include "util.h"
 
 namespace aria2 {
 
-PeerAbstractCommand::PeerAbstractCommand(cuid_t cuid,
-                                         const SharedHandle<Peer>& peer,
-                                         DownloadEngine* e,
-                                         const SocketHandle& s):
-  Command(cuid),
-  checkPoint(global::wallclock),
-  e(e),
-  socket(s),
-  peer(peer),
-  checkSocketIsReadable(false),
-  checkSocketIsWritable(false),
-  noCheck(false)
+PeerAbstractCommand::PeerAbstractCommand
+(cuid_t cuid,
+ const SharedHandle<Peer>& peer,
+ DownloadEngine* e,
+ const SocketHandle& s)
+ : Command(cuid),
+   checkPoint_(global::wallclock),
+   // TODO referring global option
+   timeout_(e->getOption()->getAsInt(PREF_BT_TIMEOUT)),
+   e_(e),
+   socket_(s),
+   peer_(peer),
+   checkSocketIsReadable_(false),
+   checkSocketIsWritable_(false),
+   noCheck_(false)
 {
-  if(!socket.isNull() && socket->isOpen()) {
-    setReadCheckSocket(socket);
+  if(socket_ && socket_->isOpen()) {
+    setReadCheckSocket(socket_);
   }
-  // TODO referring global option
-  timeout = e->option->getAsInt(PREF_BT_TIMEOUT);
 }
 
 PeerAbstractCommand::~PeerAbstractCommand()
@@ -76,44 +78,44 @@ PeerAbstractCommand::~PeerAbstractCommand()
 
 bool PeerAbstractCommand::execute()
 {
-  if(logger->debug()) {
-    logger->debug("CUID#%s -"
-                  " socket: read:%d, write:%d, hup:%d, err:%d, noCheck:%d",
-                  util::itos(cuid).c_str(),
-                  _readEvent, _writeEvent, _hupEvent, _errorEvent,
-                  noCheck);
-  }
+  A2_LOG_DEBUG(fmt("CUID#%lld -"
+                   " socket: read:%d, write:%d, hup:%d, err:%d, noCheck:%d",
+                   getCuid(),
+                   readEventEnabled(), writeEventEnabled(),
+                   hupEventEnabled(), errorEventEnabled(),
+                   noCheck_));
   if(exitBeforeExecute()) {
     onAbort();
     return true;
   }
   try {
-    if(noCheck ||
-       (checkSocketIsReadable && _readEvent) ||
-       (checkSocketIsWritable && _writeEvent) ||
-       _hupEvent) {
-      checkPoint = global::wallclock;
-    } else if(_errorEvent) {
+    if(noCheck_ ||
+       (checkSocketIsReadable_ && readEventEnabled()) ||
+       (checkSocketIsWritable_ && writeEventEnabled()) ||
+       hupEventEnabled()) {
+      checkPoint_ = global::wallclock;
+    } else if(errorEventEnabled()) {
       throw DL_ABORT_EX
-        (StringFormat(MSG_NETWORK_PROBLEM,
-                      socket->getSocketError().c_str()).str());
+        (fmt(MSG_NETWORK_PROBLEM,
+             socket_->getSocketError().c_str()));
     }
-    if(checkPoint.difference(global::wallclock) >= timeout) {
+    if(checkPoint_.difference(global::wallclock) >= timeout_) {
       throw DL_ABORT_EX(EX_TIME_OUT);
     }
     return executeInternal();
   } catch(DownloadFailureException& err) {
-    logger->error(EX_DOWNLOAD_ABORTED, err);
+    A2_LOG_ERROR_EX(EX_DOWNLOAD_ABORTED, err);
     onAbort();
-    onFailure();
+    onFailure(err);
     return true;
   } catch(RecoverableException& err) {
-    if(logger->debug()) {
-      logger->debug(MSG_TORRENT_DOWNLOAD_ABORTED, err,
-                    util::itos(cuid).c_str());
-      logger->debug(MSG_PEER_BANNED,
-                    util::itos(cuid).c_str(), peer->ipaddr.c_str(), peer->port);
-    }
+    A2_LOG_DEBUG_EX(fmt(MSG_TORRENT_DOWNLOAD_ABORTED,
+                        getCuid()),
+                    err);
+    A2_LOG_DEBUG(fmt(MSG_PEER_BANNED,
+                     getCuid(),
+                     peer_->getIPAddress().c_str(),
+                     peer_->getPort()));
     onAbort();
     return prepareForNextPeer(0);
   }
@@ -127,10 +129,10 @@ bool PeerAbstractCommand::prepareForNextPeer(time_t wait)
 
 void PeerAbstractCommand::disableReadCheckSocket()
 {
-  if(checkSocketIsReadable) {
-    e->deleteSocketForReadCheck(readCheckTarget, this);
-    checkSocketIsReadable = false;
-    readCheckTarget = SocketHandle();
+  if(checkSocketIsReadable_) {
+    e_->deleteSocketForReadCheck(readCheckTarget_, this);
+    checkSocketIsReadable_ = false;
+    readCheckTarget_.reset();
   }  
 }
 
@@ -139,26 +141,26 @@ void PeerAbstractCommand::setReadCheckSocket(const SocketHandle& socket)
   if(!socket->isOpen()) {
     disableReadCheckSocket();
   } else {
-    if(checkSocketIsReadable) {
-      if(readCheckTarget != socket) {
-        e->deleteSocketForReadCheck(readCheckTarget, this);
-        e->addSocketForReadCheck(socket, this);
-        readCheckTarget = socket;
+    if(checkSocketIsReadable_) {
+      if(*readCheckTarget_ != *socket) {
+        e_->deleteSocketForReadCheck(readCheckTarget_, this);
+        e_->addSocketForReadCheck(socket, this);
+        readCheckTarget_ = socket;
       }
     } else {
-      e->addSocketForReadCheck(socket, this);
-      checkSocketIsReadable = true;
-      readCheckTarget = socket;
+      e_->addSocketForReadCheck(socket, this);
+      checkSocketIsReadable_ = true;
+      readCheckTarget_ = socket;
     }
   }
 }
 
 void PeerAbstractCommand::disableWriteCheckSocket()
 {
-  if(checkSocketIsWritable) {
-    e->deleteSocketForWriteCheck(writeCheckTarget, this);
-    checkSocketIsWritable = false;
-    writeCheckTarget = SocketHandle();
+  if(checkSocketIsWritable_) {
+    e_->deleteSocketForWriteCheck(writeCheckTarget_, this);
+    checkSocketIsWritable_ = false;
+    writeCheckTarget_.reset();
   }
 }
 
@@ -167,28 +169,33 @@ void PeerAbstractCommand::setWriteCheckSocket(const SocketHandle& socket)
   if(!socket->isOpen()) {
     disableWriteCheckSocket();
   } else {
-    if(checkSocketIsWritable) {
-      if(writeCheckTarget != socket) {
-        e->deleteSocketForWriteCheck(writeCheckTarget, this);
-        e->addSocketForWriteCheck(socket, this);
-        writeCheckTarget = socket;
+    if(checkSocketIsWritable_) {
+      if(*writeCheckTarget_ != *socket) {
+        e_->deleteSocketForWriteCheck(writeCheckTarget_, this);
+        e_->addSocketForWriteCheck(socket, this);
+        writeCheckTarget_ = socket;
       }
     } else {
-      e->addSocketForWriteCheck(socket, this);
-      checkSocketIsWritable = true;
-      writeCheckTarget = socket;
+      e_->addSocketForWriteCheck(socket, this);
+      checkSocketIsWritable_ = true;
+      writeCheckTarget_ = socket;
     }
   }
 }
 
 void PeerAbstractCommand::setNoCheck(bool check)
 {
-  this->noCheck = check;
+  noCheck_ = check;
 }
 
 void PeerAbstractCommand::updateKeepAlive()
 {
-  checkPoint = global::wallclock;
+  checkPoint_ = global::wallclock;
+}
+
+void PeerAbstractCommand::createSocket()
+{
+  socket_.reset(new SocketCore());
 }
 
 } // namespace aria2
